summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorFathi Boudra <fabo@debian.org>2012-06-07 17:56:22 +0300
committerFathi Boudra <fabo@debian.org>2012-06-07 17:56:22 +0300
commit7dc53523d8e1c05180c147afd640418457f42a24 (patch)
tree08e3f2dfa12e3950dd3c10f9ccf9cef0a285004c
parentdd7e4fbf5018d39050e4f83e9cfff756510024eb (diff)
Switch to Nano LAVA image with pre-installed tests.
-rwxr-xr-xpost-build-lava.py28
1 files changed, 26 insertions, 2 deletions
diff --git a/post-build-lava.py b/post-build-lava.py
index cf7de96..b25a9c2 100755
--- a/post-build-lava.py
+++ b/post-build-lava.py
@@ -37,8 +37,8 @@ def main():
# Distribution, architecture and hardware pack type
ret_split = hwpack_job_name.split("-",2)
(distribution, architecture, hwpack_type) = ret_split[0], ret_split[1], ret_split[2]
- # Rootfs type, default is nano
- rootfs_type = os.getenv("ROOTFS_TYPE", "nano")
+ # Rootfs type, default is nano-lava
+ rootfs_type = os.getenv("ROOTFS_TYPE", "nano-lava")
# Bundle stream name
bundle_stream_name = os.environ.get("BUNDLE_STREAM_NAME", "/private/team/linaro/developers-and-community-builds/")
@@ -115,6 +115,30 @@ def main():
"command": "boot_linaro_image"
},
{
+ "command": "lava_test_run",
+ "parameters": {
+ "test_name": "pwrmgmt"
+ }
+ },
+ {
+ "command": "lava_test_run",
+ "parameters": {
+ "test_name": "gatortests"
+ }
+ },
+ {
+ "command": "lava_test_run",
+ "parameters": {
+ "test_name": "perf"
+ }
+ },
+ {
+ "command": "lava_test_run",
+ "parameters": {
+ "test_name": "wifi-enablement"
+ }
+ },
+ {
"command": "submit_results",
"parameters": {
"stream": bundle_stream_name,